For

Function For 

pub fn For<T, K, I, F, KFn>(props: ForProps<T, K, I, F, KFn>) -> View
where I: IntoIterator<Item = T> + 'static, F: Fn(T) -> View + Clone + 'static, KFn: Fn(&T) -> K + 'static, K: Display + 'static,
Renders a list of items using a mapping function. Currently this re-renders boundaries based on signals, but preserves syntax for keyed iteration.