Boundary

Struct Boundary 

pub struct Boundary {
    pub id: NodeId,
    pub compute: Rc<RefCell<dyn FnMut() -> View>>,
}
Represents a dynamic UI boundary.

use std::sync::mpsc;
use std::rc::Rc;
use std::cell::RefCell;
use threadloom_core::{Boundary, NodeId, View};
 
// This test proves that Boundary cannot cross threads!
// If someone tries to send a Boundary over a channel, it will fail to compile
// because Boundary contains an Rc.
let (tx, rx) = mpsc::channel::<Boundary>();
std::thread::spawn(move || {
    // tx is moved into the thread, requiring T (Boundary) to be Send
});

Fields

id: NodeIdcompute: Rc<RefCell<dyn FnMut() -> View>>